@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::AdDynamicTextPerformanceReportFilter;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -27,6 +27,7 @@ our @_attributes = (qw/
     AdType
     DeviceType
     LanguageAndRegion
+    LanguageCode
 /);
 
 sub _attributes {
@@ -39,6 +40,7 @@ our %_attribute_type = (
     AdType => 'AdTypeReportFilter',
     DeviceType => 'DeviceTypeReportFilter',
     LanguageAndRegion => 'LanguageAndRegionReportFilter',
+    LanguageCode => 'ArrayOfstring',
 );
 
 sub _attribute_type {
@@ -54,6 +56,7 @@ our %_attribute_min_occurs = (
     AdType => 0,
     DeviceType => 0,
     LanguageAndRegion => 0,
+    LanguageCode => 0,
 );
 
 sub _attribute_min_occurs {
@@ -96,5 +99,9 @@ Gets/sets DeviceType (DeviceTypeReportFilter)
 
 Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
 
+=head2 LanguageCode
+
+Gets/sets LanguageCode (ArrayOfstring)
+
 =cut
 
