@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::V7::ReportingService::AdPerformanceReportColumn;
-# Copyright (C) 2011 Xerxes Tsang
+# Copyright (C) 2012 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -37,7 +37,9 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
     CurrencyCode
     DestinationUrl
     DeviceType
+    DisplayUrl
     Impressions
+    Language
     LanguageAndRegion
     PricingModel
     Spend
@@ -129,10 +131,18 @@ sub DeviceType {
     return 'DeviceType';
 }
 
+sub DisplayUrl {
+    return 'DisplayUrl';
+}
+
 sub Impressions {
     return 'Impressions';
 }
 
+sub Language {
+    return 'Language';
+}
+
 sub LanguageAndRegion {
     return 'LanguageAndRegion';
 }
