@@ -16,6 +16,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
 
 =head1 ENUMERATION VALUES
 
+    Aggregate
     Broad
     Content
     Exact
@@ -23,6 +24,10 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
 
 =cut
 
+sub Aggregate {
+    return 'Aggregate';
+}
+
 sub Broad {
     return 'Broad';
 }
