@@ -18,6 +18,7 @@ See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation o
 
     Failed
     InProgress
+    PartialSuccess
     Success
 
 =cut
@@ -30,6 +31,10 @@ sub InProgress {
     return 'InProgress';
 }
 
+sub PartialSuccess {
+    return 'PartialSuccess';
+}
+
 sub Success {
     return 'Success';
 }
